/* squidclamav.h */

/*
  SquidClamav - A Clamav Antivirus Redirector for Squid
  
  Copyright (C) 2005-2010 Gilles Darold

        This program is free software: you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation, either version 3 of the License, or
        any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program.  If not, see < http://www.gnu.org/licenses/ >.

*/


#ifndef SQUIDCLAMAV_H

#define SQUIDCLAMAV_H 1

/*************  Default configuration file location  ***********/
#define CONFIG_FILE "/etc/squidclamav.conf"

/************* Proxy configuration *************/
#define PROXY_SERVER "127.0.0.1"
#define PROXY_PORT "3128"


/************* Default Clamd configuration *************/
#define CLAMD_SERVER "127.0.0.1" 
#define CLAMD_PORT "3310" 
/* Define a 1000ms timeout to connect to clamd */
#define CLAMD_TIMEOUT "1000"


# ifdef S_SPLINT_S
extern char *strdup (char *s) /*@*/ ;
#endif

#include<stdarg.h>
#include<sys/types.h>
#include<regex.h>
#define LOW_CHAR 32
#define SMALL_CHAR 128
#define LOW_BUFF 256
#define SMALL_BUFF 1024
#define NORMAL_BUFF 4096
#define MAX_URL  8192
#define MAX_LOGIN_SZ 128

struct IN_BUFF {
  char url[MAX_URL];
  char src_address[1050];
  char ident[MAX_LOGIN_SZ];
  char method[LOW_CHAR];
  char ipaddress[16];
  char fqdn[1024];
};

#define WHITELIST    1
#define TRUSTUSER    2
#define TRUSTCLIENT  3
#define ABORT        4
#define ABORTCONTENT 5

#define ACCEL_NORMAL 1
#define ACCEL_START  2
#define ACCEL_END    3

#define PATTERN_ARR_SIZE 32	/* Array of 32 patterns */

struct IP {
  short first;
  short second;
  short third;
};

typedef struct {
  char *pattern;
  int type;
  int flag;
  regex_t regexv;
} SCPattern;

void add_pattern(char *s);
void regcomp_pattern(void);
int load_in_buff(char *);
int simple_pattern_compare(char *, const int );
int client_pattern_compare(char *, char *);
void load_patterns(void);


#endif


